@@ -20,7 +20,7 @@ our $VERSION;
 our $DEBUG;
 
 BEGIN {
-  our $VERSION = qv(8.1.7);
+  our $VERSION = qv(8.1.8);
   XSLoader::load("sealed", $VERSION);
 }
 
@@ -85,7 +85,7 @@ sub tweak :prototype($\@\@\@$$\%) {
           local $@;
           eval {warn "sub ", $cv_obj->GV->NAME // "__UNKNOWN__", " :sealed ",
                   B::Deparse->new->coderef2text($cv_obj->object_2svref), "\n"};
-          Carp::confess ("sealed failed: $_[0]->$method_name method lookup differs " .
+          Carp::confess ("sealed verify failed: $_[0]->$method_name method lookup differs " .
                          "from $class->$method_name:FAILED lookup");
         };
 
@@ -256,7 +256,7 @@ sub filter {
     }
 
      $prefix .= " ($_,\@_dummy)" if $DEBUG eq "verify"; # keep untyped sigs for perl verification
-    warn "$prefix { CHECK{ $t } $suffix";
+    # warn "$prefix { CHECK{ $t } $suffix";
     "$prefix { no warnings qw/experimental shadow/; CHECK{ $t } $suffix";
   )gmsex if $status > 0;
 
